@@ -45,6 +45,7 @@ class QCandlestickLegendMarker;
 class QCandlestickModelMapper;
 class QCandlestickSeries;
 class QCandlestickSet;
+class QColorAxis;
 class QDateTimeAxis;
 class QHBarModelMapper;
 class QHBoxPlotModelMapper;
@@ -98,51 +99,52 @@ enum : int {
     SBK_QCHART_CHARTTYPE_IDX                                 = 27,
     SBK_QCHART_CHARTTHEME_IDX                                = 26,
     SBK_QCHART_ANIMATIONOPTION_IDX                           = 25,
-    SBK_QFLAGS_QCHART_ANIMATIONOPTION_IDX                    = 31,
+    SBK_QFLAGS_QCHART_ANIMATIONOPTION_IDX                    = 32,
     SBK_QCHART_IDX                                           = 24,
     SBK_QCHARTVIEW_RUBBERBAND_IDX                            = 29,
-    SBK_QFLAGS_QCHARTVIEW_RUBBERBAND_IDX                     = 32,
+    SBK_QFLAGS_QCHARTVIEW_RUBBERBAND_IDX                     = 33,
     SBK_QCHARTVIEW_IDX                                       = 28,
-    SBK_QDATETIMEAXIS_IDX                                    = 30,
-    SBK_QHBARMODELMAPPER_IDX                                 = 34,
-    SBK_QHBOXPLOTMODELMAPPER_IDX                             = 35,
-    SBK_QHCANDLESTICKMODELMAPPER_IDX                         = 36,
-    SBK_QHPIEMODELMAPPER_IDX                                 = 37,
-    SBK_QHXYMODELMAPPER_IDX                                  = 38,
-    SBK_QHORIZONTALBARSERIES_IDX                             = 39,
-    SBK_QHORIZONTALPERCENTBARSERIES_IDX                      = 40,
-    SBK_QHORIZONTALSTACKEDBARSERIES_IDX                      = 41,
-    SBK_QLEGEND_MARKERSHAPE_IDX                              = 43,
-    SBK_QLEGEND_IDX                                          = 42,
-    SBK_QLEGENDMARKER_LEGENDMARKERTYPE_IDX                   = 45,
-    SBK_QLEGENDMARKER_IDX                                    = 44,
-    SBK_QLINESERIES_IDX                                      = 46,
-    SBK_QLOGVALUEAXIS_IDX                                    = 47,
-    SBK_QPERCENTBARSERIES_IDX                                = 48,
-    SBK_QPIELEGENDMARKER_IDX                                 = 49,
-    SBK_QPIEMODELMAPPER_IDX                                  = 50,
-    SBK_QPIESERIES_IDX                                       = 51,
-    SBK_QPIESLICE_LABELPOSITION_IDX                          = 53,
-    SBK_QPIESLICE_IDX                                        = 52,
-    SBK_QPOLARCHART_POLARORIENTATION_IDX                     = 55,
-    SBK_QFLAGS_QPOLARCHART_POLARORIENTATION_IDX              = 33,
-    SBK_QPOLARCHART_IDX                                      = 54,
-    SBK_QSCATTERSERIES_MARKERSHAPE_IDX                       = 57,
-    SBK_QSCATTERSERIES_IDX                                   = 56,
-    SBK_QSPLINESERIES_IDX                                    = 58,
-    SBK_QSTACKEDBARSERIES_IDX                                = 59,
-    SBK_QVBARMODELMAPPER_IDX                                 = 60,
-    SBK_QVBOXPLOTMODELMAPPER_IDX                             = 61,
-    SBK_QVCANDLESTICKMODELMAPPER_IDX                         = 62,
-    SBK_QVPIEMODELMAPPER_IDX                                 = 63,
-    SBK_QVXYMODELMAPPER_IDX                                  = 64,
-    SBK_QVALUEAXIS_TICKTYPE_IDX                              = 66,
-    SBK_QVALUEAXIS_IDX                                       = 65,
-    SBK_QXYLEGENDMARKER_IDX                                  = 67,
-    SBK_QXYMODELMAPPER_IDX                                   = 68,
-    SBK_QXYSERIES_POINTCONFIGURATION_IDX                     = 70,
-    SBK_QXYSERIES_IDX                                        = 69,
-    SBK_QtCharts_IDX_COUNT                                   = 71
+    SBK_QCOLORAXIS_IDX                                       = 30,
+    SBK_QDATETIMEAXIS_IDX                                    = 31,
+    SBK_QHBARMODELMAPPER_IDX                                 = 35,
+    SBK_QHBOXPLOTMODELMAPPER_IDX                             = 36,
+    SBK_QHCANDLESTICKMODELMAPPER_IDX                         = 37,
+    SBK_QHPIEMODELMAPPER_IDX                                 = 38,
+    SBK_QHXYMODELMAPPER_IDX                                  = 39,
+    SBK_QHORIZONTALBARSERIES_IDX                             = 40,
+    SBK_QHORIZONTALPERCENTBARSERIES_IDX                      = 41,
+    SBK_QHORIZONTALSTACKEDBARSERIES_IDX                      = 42,
+    SBK_QLEGEND_MARKERSHAPE_IDX                              = 44,
+    SBK_QLEGEND_IDX                                          = 43,
+    SBK_QLEGENDMARKER_LEGENDMARKERTYPE_IDX                   = 46,
+    SBK_QLEGENDMARKER_IDX                                    = 45,
+    SBK_QLINESERIES_IDX                                      = 47,
+    SBK_QLOGVALUEAXIS_IDX                                    = 48,
+    SBK_QPERCENTBARSERIES_IDX                                = 49,
+    SBK_QPIELEGENDMARKER_IDX                                 = 50,
+    SBK_QPIEMODELMAPPER_IDX                                  = 51,
+    SBK_QPIESERIES_IDX                                       = 52,
+    SBK_QPIESLICE_LABELPOSITION_IDX                          = 54,
+    SBK_QPIESLICE_IDX                                        = 53,
+    SBK_QPOLARCHART_POLARORIENTATION_IDX                     = 56,
+    SBK_QFLAGS_QPOLARCHART_POLARORIENTATION_IDX              = 34,
+    SBK_QPOLARCHART_IDX                                      = 55,
+    SBK_QSCATTERSERIES_MARKERSHAPE_IDX                       = 58,
+    SBK_QSCATTERSERIES_IDX                                   = 57,
+    SBK_QSPLINESERIES_IDX                                    = 59,
+    SBK_QSTACKEDBARSERIES_IDX                                = 60,
+    SBK_QVBARMODELMAPPER_IDX                                 = 61,
+    SBK_QVBOXPLOTMODELMAPPER_IDX                             = 62,
+    SBK_QVCANDLESTICKMODELMAPPER_IDX                         = 63,
+    SBK_QVPIEMODELMAPPER_IDX                                 = 64,
+    SBK_QVXYMODELMAPPER_IDX                                  = 65,
+    SBK_QVALUEAXIS_TICKTYPE_IDX                              = 67,
+    SBK_QVALUEAXIS_IDX                                       = 66,
+    SBK_QXYLEGENDMARKER_IDX                                  = 68,
+    SBK_QXYMODELMAPPER_IDX                                   = 69,
+    SBK_QXYSERIES_POINTCONFIGURATION_IDX                     = 71,
+    SBK_QXYSERIES_IDX                                        = 70,
+    SBK_QtCharts_IDX_COUNT                                   = 72
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtChartsTypes;
@@ -218,6 +220,7 @@ template<> inline PyTypeObject *SbkType< ::QChart >() { return reinterpret_cast<
 template<> inline PyTypeObject *SbkType< ::QChartView::RubberBand >() { return SbkPySide6_QtChartsTypes[SBK_QCHARTVIEW_RUBBERBAND_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QChartView::RubberBand> >() { return SbkPySide6_QtChartsTypes[SBK_QFLAGS_QCHARTVIEW_RUBBERBAND_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QChartView >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QCHARTVIEW_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QColorAxis >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QCOLORAXIS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QDateTimeAxis >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QDATETIMEAXIS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHBarModelMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QHBARMODELMAPPER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHBoxPlotModelMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QHBOXPLOTMODELMAPPER_IDX]); }
