@@ -52,10 +52,10 @@ class QQmlTypesExtensionInterface;
 
 using AtomicBool = std::atomic<bool>;
 
-typedef struct {
+struct QtQml_VolatileBoolObject {
     PyObject_HEAD
     AtomicBool *flag;
-} QtQml_VolatileBoolObject;
+};
 // End of code injection
 
 // Type indices
